@@ -56,7 +56,7 @@
     <name>ConfigPlacement</name>
     <message>
         <location filename="../config/configplacement.ui" line="20"/>
-        <source>Configure placement</source>
+        <source>Configure Placement</source>
         <translation>Nastavit umístění</translation>
     </message>
     <message>
@@ -376,45 +376,45 @@ Obarvit ikony podle stylu prvku (paleta)</translation>
 <context>
     <name>LXQtPanel</name>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1325"/>
-        <location filename="../lxqtpanel.cpp" line="1351"/>
+        <location filename="../lxqtpanel.cpp" line="1361"/>
+        <location filename="../lxqtpanel.cpp" line="1387"/>
         <source>Panel</source>
         <translation>Panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1354"/>
+        <location filename="../lxqtpanel.cpp" line="1390"/>
         <source>Configure Panel</source>
         <translation>Nastavit panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1359"/>
+        <location filename="../lxqtpanel.cpp" line="1395"/>
         <source>Manage Widgets</source>
         <translation>Spravovat ovládací prvky</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1365"/>
+        <location filename="../lxqtpanel.cpp" line="1401"/>
         <source>Add New Panel</source>
         <translation>Přidat nový panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1372"/>
+        <location filename="../lxqtpanel.cpp" line="1408"/>
         <source>Remove Panel</source>
         <comment>Menu Item</comment>
         <translation>Odstranit panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1377"/>
+        <location filename="../lxqtpanel.cpp" line="1413"/>
         <source>Lock This Panel</source>
         <translation>Zamknout tento panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1533"/>
+        <location filename="../lxqtpanel.cpp" line="1576"/>
         <source>Remove Panel</source>
         <comment>Dialog Title</comment>
         <translation>Odstranit panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1534"/>
+        <location filename="../lxqtpanel.cpp" line="1577"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
         <translation>Odstranění panelu nelze vrátit zpět.
@@ -442,12 +442,12 @@ Opravdu chcete tento panel odstranit?</translation>
 <context>
     <name>main</name>
     <message>
-        <location filename="../lxqtpanelapplication.cpp" line="95"/>
+        <location filename="../lxqtpanelapplication.cpp" line="340"/>
         <source>Use alternate configuration file.</source>
         <translation>Použít jiný soubor s nastaveními.</translation>
     </message>
     <message>
-        <location filename="../lxqtpanelapplication.cpp" line="96"/>
+        <location filename="../lxqtpanelapplication.cpp" line="341"/>
         <source>Configuration file</source>
         <translation>Soubor s nastaveními</translation>
     </message>
