@@ -16,7 +16,7 @@
     <message>
         <location filename="../config/addplugindialog.ui" line="102"/>
         <source>Add Widget</source>
-        <translation>Legg til widget</translation>
+        <translation>Legg til modul</translation>
     </message>
     <message>
         <location filename="../config/addplugindialog.ui" line="112"/>
@@ -49,14 +49,14 @@
     <message>
         <location filename="../config/configpaneldialog.cpp" line="47"/>
         <source>Widgets</source>
-        <translation>Widgeter</translation>
+        <translation>Moduler</translation>
     </message>
 </context>
 <context>
     <name>ConfigPlacement</name>
     <message>
         <location filename="../config/configplacement.ui" line="20"/>
-        <source>Configure placement</source>
+        <source>Configure Placement</source>
         <translation>Plasseringsvalg</translation>
     </message>
     <message>
@@ -87,18 +87,18 @@
     <message>
         <location filename="../config/configplacement.ui" line="101"/>
         <source>px</source>
-        <translation>pk</translation>
+        <translation>px</translation>
     </message>
     <message>
         <location filename="../config/configplacement.ui" line="109"/>
         <location filename="../config/configplacement.ui" line="153"/>
         <source> px</source>
-        <translation> pk</translation>
+        <translation> px</translation>
     </message>
     <message>
         <location filename="../config/configplacement.ui" line="166"/>
         <source>Icon size:</source>
-        <translation>Symbolstørrelse:</translation>
+        <translation>Ikonstørrelse:</translation>
     </message>
     <message>
         <location filename="../config/configplacement.ui" line="173"/>
@@ -253,7 +253,7 @@
     <message>
         <location filename="../config/configpluginswidget.ui" line="84"/>
         <source>Note: changes made in this page cannot be reset.</source>
-        <translation>Obs: Forandringer gjort på denne siden kan ikke stilles om.</translation>
+        <translation>Merk: Forandringer gjort på denne siden kan ikke tilbakestilles.</translation>
     </message>
     <message>
         <location filename="../config/configpluginswidget.ui" line="112"/>
@@ -315,7 +315,7 @@
     <message>
         <location filename="../config/configstyling.ui" line="144"/>
         <source>Background opacity:</source>
-        <translation>Bakgrunnsgjennomsiktighet:</translation>
+        <translation>Bakgrunnsugjennomsiktighet:</translation>
     </message>
     <message>
         <location filename="../config/configstyling.ui" line="176"/>
@@ -337,24 +337,24 @@ You might also want to disable:
 LXQt Appearance Configuration →
 Icons Theme →
 Colorize icons based on widget style (palette)</source>
-        <translation>En delvis fiks for widget-stiler som ikke
-kan gi et eget tema til panelet.
+        <translation>En delvis løsning for widget-stiler som
+ikke kan gi et separat tema til panelet.
 
-Du ønsker kanskje også å skru av:
+Du ønsker kanskje også å slå av:
 
 LXQt Utseendeinnstillinger →
-Symboltema →
-Fargelegg symboler basert på widget-stil (pallett)</translation>
+Ikontema →
+Fargelegg ikoner basert på widget-stil (palett)</translation>
     </message>
     <message>
         <location filename="../config/configstyling.ui" line="266"/>
         <source>Override icon &amp;theme</source>
-        <translation>Overkjør symbo&amp;ltema</translation>
+        <translation>Overstyr ikon&amp;tema</translation>
     </message>
     <message>
         <location filename="../config/configstyling.ui" line="281"/>
         <source>Icon theme for panels:</source>
-        <translation>Symboltema for paneler:</translation>
+        <translation>Ikontema for paneler:</translation>
     </message>
     <message>
         <location filename="../config/configstyling.cpp" line="189"/>
@@ -376,45 +376,45 @@ Fargelegg symboler basert på widget-stil (pallett)</translation>
 <context>
     <name>LXQtPanel</name>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1325"/>
-        <location filename="../lxqtpanel.cpp" line="1351"/>
+        <location filename="../lxqtpanel.cpp" line="1361"/>
+        <location filename="../lxqtpanel.cpp" line="1387"/>
         <source>Panel</source>
         <translation>Panelet</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1354"/>
+        <location filename="../lxqtpanel.cpp" line="1390"/>
         <source>Configure Panel</source>
         <translation>Konfigurer panelet</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1359"/>
+        <location filename="../lxqtpanel.cpp" line="1395"/>
         <source>Manage Widgets</source>
-        <translation>Styr widgeter</translation>
+        <translation>Håndter moduler</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1365"/>
+        <location filename="../lxqtpanel.cpp" line="1401"/>
         <source>Add New Panel</source>
         <translation>Legg til nytt panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1372"/>
+        <location filename="../lxqtpanel.cpp" line="1408"/>
         <source>Remove Panel</source>
         <comment>Menu Item</comment>
         <translation>Fjern panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1377"/>
+        <location filename="../lxqtpanel.cpp" line="1413"/>
         <source>Lock This Panel</source>
         <translation>Lås dette panelet</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1533"/>
+        <location filename="../lxqtpanel.cpp" line="1576"/>
         <source>Remove Panel</source>
         <comment>Dialog Title</comment>
         <translation>Fjern panel</translation>
     </message>
     <message>
-        <location filename="../lxqtpanel.cpp" line="1534"/>
+        <location filename="../lxqtpanel.cpp" line="1577"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
         <translation>Å fjerne panelet kan ikke omgjøres.
@@ -442,12 +442,12 @@ Do you want to remove this panel?</source>
 <context>
     <name>main</name>
     <message>
-        <location filename="../lxqtpanelapplication.cpp" line="95"/>
+        <location filename="../lxqtpanelapplication.cpp" line="340"/>
         <source>Use alternate configuration file.</source>
         <translation>Bruk en alternativ konfigurasjonsfil.</translation>
     </message>
     <message>
-        <location filename="../lxqtpanelapplication.cpp" line="96"/>
+        <location filename="../lxqtpanelapplication.cpp" line="341"/>
         <source>Configuration file</source>
         <translation>Konfigurasjonsfil</translation>
     </message>
